# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .project_risk_factor import ProjectRiskFactor
from .trade_counts import TradeCounts
from .upstream_count import UpstreamCount
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class UpstreamInfo(UniversalBaseModel):
    risk_factors: typing.List[ProjectRiskFactor]
    countries: typing.List[str]
    trade_counts: TradeCounts
    has_upstream: bool
    products: typing.List[str]
    risk_counts: typing.Optional[UpstreamCount] = None
    country_counts: typing.Optional[UpstreamCount] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .project_entity_response import ProjectEntityResponse
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class SingleProjectEntityResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity import (
        Address,
        AttributeValues,
        BusinessPurpose,
        ProjectEntityMatchExplanation,
        ProjectEntityMatchResponse,
        ProjectEntityResponse,
        ProjectRiskCategory,
        ProjectRiskFactor,
        SingleProjectEntityResponse,
        SourceField,
        TradeCounts,
        UpstreamInfo,
    )

    SingleProjectEntityResponse(
        data=ProjectEntityResponse(
            project_entity_id="52z4Wa",
            project_id="YVB88Y",
            label="VTB Bank",
            upload_ids=[],
            strength="strong",
            created_at="2025-04-22 22:54:00.913586+00",
            attributes={
                "name": AttributeValues(
                    match_resolution=True,
                    values=["VTB Bank"],
                ),
                "country": AttributeValues(
                    match_resolution=True,
                    values=["RUS"],
                ),
                "address": AttributeValues(
                    match_resolution=True,
                    values=["Moscow"],
                ),
                "identifier": AttributeValues(
                    match_resolution=True,
                    values=["253400V1H6ART1UQ0N98"],
                ),
            },
            countries=[
                "USA",
                "CYP",
                "ITA",
                "CHN",
                "RUS",
                "UKR",
                "IND",
                "IRL",
                "KAZ",
                "DEU",
            ],
            risk_categories=[
                ProjectRiskCategory(
                    id="regulatory_action",
                    label="Regulatory action",
                    risk_factors=["regulatory_action"],
                ),
                ProjectRiskCategory(
                    id="export_controls",
                    label="Export controls",
                    risk_factors=["meu_list_contractors", "export_controls"],
                ),
                ProjectRiskCategory(
                    id="political_exposure",
                    label="Political exposure",
                    risk_factors=["soe_adjacent", "pep_adjacent"],
                ),
                ProjectRiskCategory(
                    id="sanctions",
                    label="Sanctions",
                    risk_factors=["sanctioned", "formerly_sanctioned"],
                ),
                ProjectRiskCategory(
                    id="adverse_media",
                    label="Adverse media",
                    risk_factors=["reputational_risk_other"],
                ),
            ],
            risk_factors=[
                ProjectRiskFactor(
                    id="regulatory_action",
                ),
                ProjectRiskFactor(
                    id="sanctioned",
                ),
                ProjectRiskFactor(
                    id="meu_list_contractors",
                ),
                ProjectRiskFactor(
                    id="reputational_risk_other",
                ),
                ProjectRiskFactor(
                    id="pep_adjacent",
                ),
                ProjectRiskFactor(
                    id="state_owned",
                ),
                ProjectRiskFactor(
                    id="export_controls",
                ),
                ProjectRiskFactor(
                    id="formerly_sanctioned",
                ),
                ProjectRiskFactor(
                    id="basel_aml",
                ),
                ProjectRiskFactor(
                    id="cpi_score",
                ),
            ],
            upstream=UpstreamInfo(
                risk_factors=[],
                countries=[],
                trade_counts=TradeCounts(
                    shipper_of=56,
                    receiver_of=2,
                ),
                has_upstream=False,
                products=[],
            ),
            tags=[],
            case="not_assigned",
            matches=[
                ProjectEntityMatchResponse(
                    match_id="52z4Wa:dy-rh2g0QtzUN_jC_e9S_A",
                    sayari_entity_id="dy-rh2g0QtzUN_jC_e9S_A",
                    type="company",
                    label='ОТКРЫТОЕ АКЦИОНЕРНОЕ ОБЩЕСТВО "РОССИЙСКИЕ ЖЕЛЕЗНЫЕ ДОРОГИ"',
                    match_explanation=[
                        ProjectEntityMatchExplanation(
                            field="name",
                            quality="high",
                            matches=[
                                "<em>БАНК</em> <em>ВТБ</em> (ПАО)",
                                "<em>VTB</em> <em>BANK</em> (PJSC)",
                                "<em>БАНК</em> <em>ВТБ</em> (ПУБЛИЧНОЕ АКЦИОНЕРНОЕ ОБЩЕСТВО)",
                                "<em>VTB</em> <em>BANK</em> (PUBLIC JOINT STOCK COMPANY)",
                                "<em>VTB</em> <em>Bank</em>",
                            ],
                        ),
                        ProjectEntityMatchExplanation(
                            field="address",
                            quality="medium",
                            matches=[
                                "109147 <em>Moscow</em>, st. Vorontsovskaya, 43 building 1",
                                "119121 <em>Moscow</em>, st. Plyushchikha, 37.",
                                "Vorontsovskaya Str., 43 <em>Moscow</em> 109044 RUSSIAN FEDERATION",
                                "37 Plyushchikha ul., <em>Moscow</em>, 119121, Russia",
                                "Bashnya Zapad, Kompleks Federatsiya, 12, nab. Presnenskaya, <em>Moscow</em>, 123317, Russia",
                            ],
                        ),
                        ProjectEntityMatchExplanation(
                            field="country",
                            quality="high",
                            matches=["<em>RUS</em>"],
                        ),
                        ProjectEntityMatchExplanation(
                            field="identifier",
                            quality="high",
                            matches=["<em>253400V1H6ART1UQ0N98</em>"],
                        ),
                    ],
                    countries=[
                        "USA",
                        "CYP",
                        "ITA",
                        "CHN",
                        "RUS",
                        "UKR",
                        "IND",
                        "IRL",
                        "KAZ",
                        "DEU",
                    ],
                    risk_categories=[
                        ProjectRiskCategory(
                            id="regulatory_action",
                            label="Regulatory action",
                            risk_factors=["regulatory_action"],
                        ),
                        ProjectRiskCategory(
                            id="export_controls",
                            label="Export controls",
                            risk_factors=[
                                "meu_list_contractors",
                                "export_controls",
                            ],
                        ),
                        ProjectRiskCategory(
                            id="political_exposure",
                            label="Political exposure",
                            risk_factors=["soe_adjacent", "pep_adjacent"],
                        ),
                        ProjectRiskCategory(
                            id="sanctions",
                            label="Sanctions",
                            risk_factors=["sanctioned", "formerly_sanctioned"],
                        ),
                        ProjectRiskCategory(
                            id="adverse_media",
                            label="Adverse media",
                            risk_factors=["reputational_risk_other"],
                        ),
                    ],
                    risk_factors=[
                        ProjectRiskFactor(
                            id="regulatory_action",
                        ),
                        ProjectRiskFactor(
                            id="sanctioned",
                        ),
                        ProjectRiskFactor(
                            id="meu_list_contractors",
                        ),
                        ProjectRiskFactor(
                            id="reputational_risk_other",
                        ),
                        ProjectRiskFactor(
                            id="pep_adjacent",
                        ),
                        ProjectRiskFactor(
                            id="state_owned",
                        ),
                        ProjectRiskFactor(
                            id="export_controls",
                        ),
                        ProjectRiskFactor(
                            id="formerly_sanctioned",
                        ),
                        ProjectRiskFactor(
                            id="basel_aml",
                        ),
                        ProjectRiskFactor(
                            id="cpi_score",
                        ),
                    ],
                    business_purpose=[
                        BusinessPurpose(
                            standard="ISIC4",
                            code="6419",
                        ),
                        BusinessPurpose(
                            code="64.19",
                            standard="unknown",
                        ),
                        BusinessPurpose(
                            code="64.9",
                            standard="unknown",
                        ),
                        BusinessPurpose(
                            code="62.09",
                            standard="unknown",
                        ),
                        BusinessPurpose(
                            standard="NACE2",
                            code="64.19",
                        ),
                        BusinessPurpose(
                            code="64.19",
                            standard="unknown",
                        ),
                        BusinessPurpose(
                            standard="ISIC4",
                            code="649",
                        ),
                        BusinessPurpose(
                            code="66.12",
                            standard="unknown",
                        ),
                        BusinessPurpose(
                            standard="ISIC4",
                            code="6419",
                        ),
                        BusinessPurpose(
                            standard="ISIC4",
                            code="6209",
                        ),
                        BusinessPurpose(
                            standard="ISIC4",
                            code="6612",
                        ),
                    ],
                    upstream=UpstreamInfo(
                        risk_factors=[],
                        countries=[],
                        trade_counts=TradeCounts(
                            shipper_of=56,
                            receiver_of=2,
                        ),
                        has_upstream=False,
                        products=[],
                        risk_counts={},
                        country_counts={},
                    ),
                    sources=[
                        SourceField(
                            id="eb361ba33d05a9d15b2d28aea739362a",
                            label="USA SEC Central Index Key Database",
                        ),
                        SourceField(
                            id="a8c6ee1cd4dfc952105ee8c0e4836f08",
                            label="Acuris Risk Intelligence KYC6 (3rd Party Data)",
                        ),
                        SourceField(
                            id="3322a755c28851ec06eda3280cc2a2b2",
                            label="Russia ClearSpending (3rd Party Data)",
                        ),
                        SourceField(
                            id="93de05b55a68cc964f34bbfc7ec7bc86",
                            label="Consolidated Canadian Autonomous Sanctions List",
                        ),
                        SourceField(
                            id="fdfedf11a5122e2aef9dc3f176c7427d",
                            label="Sayari Intel (Sayari Curated Risk Data) - Archived",
                        ),
                        SourceField(
                            id="e517c714b560f159a89a9501ed7dd84e",
                            label="Infocredit Cyprus Company Shareholders Database (3rd Party Data)",
                        ),
                        SourceField(
                            id="bef2f30139ea37c723ecb0f953b5f024",
                            label="Australia Consolidated Sanctions List",
                        ),
                        SourceField(
                            id="9048153c770d941afe9500c6ad810a80",
                            label="Kazakhstan DFO Registry",
                        ),
                        SourceField(
                            id="635021e4e01979cdf95fa7ee76501696",
                            label="Russia E-Disclosures",
                        ),
                        SourceField(
                            id="e85d865943ee6d8369307569d2ad9de0",
                            label="Acuris Risk Intelligence Adverse Media Data",
                        ),
                        SourceField(
                            id="4ff85397f508e4ff8e71c5ca5ea895dd",
                            label="Japan Ministry of Finance Economic Sanctions List",
                        ),
                        SourceField(
                            id="ce873f184abee5b13c9e89791bd78229",
                            label="Ukraine Significant Shareholders of Securities Issuers",
                        ),
                        SourceField(
                            id="8511f57f6098dcc36e3a814c3ea5bdd7",
                            label="Uzbekistan Imports & Exports (January 2022 - Present)",
                        ),
                        SourceField(
                            id="e6e4acebdea4e9e71af8d3586d34fcdd",
                            label="Ukraine Sanctions List",
                        ),
                        SourceField(
                            id="db3416894cd5f0c4d2d6ecc79bdaf366",
                            label="EDI Publicly-Listed Global Security Issuers (3rd Party Data)",
                        ),
                        SourceField(
                            id="b812677c0a32a1746b3ac741c7b97ae0",
                            label="Legal Entity Identifier (LEI) Registry (3rd Party Data)",
                        ),
                        SourceField(
                            id="a9a18eeb901e4376c912e95dc05ceb78",
                            label="Russia Federal Tax Registry",
                        ),
                        SourceField(
                            id="d357238101a2bb02d97d5d77a56d9455",
                            label="New Zealand Russia Sanctions",
                        ),
                        SourceField(
                            id="f4ce10ac8bdc0bd9bcb31cb868b4b539",
                            label="EU Financial Sanctions List",
                        ),
                        SourceField(
                            id="c10d482320f207d92aa814519c3bd686",
                            label="UK Consolidated Sanctions List",
                        ),
                        SourceField(
                            id="d1bce737c158efddbef5048d63aaf124",
                            label="Ukraine Ministry of Justice Registry of Companies",
                        ),
                        SourceField(
                            id="92edb8fe6615498f6e3e7b0e220f74e6",
                            label="USA Treasury OFAC Specially Designated Nationals (SDN) List",
                        ),
                        SourceField(
                            id="66dfefb726ae00fde8f09f34c5578d35",
                            label="Russia Imports & Exports (January 2023 - Present)",
                        ),
                        SourceField(
                            id="ad6dc774c74b92159422deabc5aee661",
                            label="France National Asset Freeze Register",
                        ),
                        SourceField(
                            id="b97ad5c858093e5227b2359a0078696f",
                            label="USA SAM.gov Entity Exclusions Database",
                        ),
                        SourceField(
                            id="ddbf93a5c5d568ccdb0c2455f7ecbfc8",
                            label="USA CorpWatch SEC 10-K Exhibit 21 Database (3rd Party Data)",
                        ),
                        SourceField(
                            id="52a7bc4a30e787544ad2d95e7f54adca",
                            label="USA OFAC Non-SDN Consolidated Sanctions List",
                        ),
                        SourceField(
                            id="f43658cf2a19452fb45b830edeeeea44",
                            label="Russia Central Bank Financial Institution UBO Disclosures",
                        ),
                        SourceField(
                            id="828f81c7c31410de845d9e6ed1a0f3e6",
                            label="Russia Central Bank Financial Institutions",
                        ),
                        SourceField(
                            id="56bce0e008204712e302271ddd7b4fb1",
                            label="Russia Federal Tax Registry (2018)",
                        ),
                        SourceField(
                            id="e0b32f41da3b4e6c75f1f7bf6fe1c9c5",
                            label="S&P Global Market Intelligence Database (3rd Party Data)",
                        ),
                        SourceField(
                            id="10a889609ddae6cc31773feebe48166b",
                            label="Switzerland SECO Sanctions List",
                        ),
                        SourceField(
                            id="ded706ef28cdc649b6fc5142bc542890",
                            label="EU Sanctions Map",
                        ),
                        SourceField(
                            id="417400a1ac439843fda5bb2f05fb4161",
                            label="USA Consolidated Screening List",
                        ),
                        SourceField(
                            id="765d0dc816bb7db35031c43a37290350",
                            label="Ireland Companies Registration Office Database",
                        ),
                    ],
                    addresses=[
                        Address(
                            value="190000, г Санкт-Петербург, ул Большая Морская, дом 29",
                        ),
                        Address(
                            value="109147 г. Москва, ул. Воронцовская, д.43 стр.1",
                        ),
                        Address(
                            value="119121 г. Москва, ул. Плющиха, д. 37.",
                        ),
                        Address(
                            value="43, Vorontsovskaya str., Moscow, 109044, Russia",
                        ),
                        Address(
                            value="11, lit A, Degtyarnyy pereulok, St. Petersburg, 191144, Russia",
                        ),
                        Address(
                            value="29, Bolshaya Morskaya str., St. Petersburg, 190000, Russia",
                        ),
                    ],
                    hs_codes=[
                        "847150",
                        "8471500000",
                        "852351",
                        "8523519101",
                        "860610",
                        "8606100000",
                        "271019",
                        "2710196601",
                        "490700",
                        "4907003000",
                        "711890",
                        "7118900000",
                        "490700",
                        "4907003000",
                        "711890",
                        "7118900000",
                    ],
                    created_at="2025-04-22 22:54:00.913586+00",
                    updated_at="2025-04-22 22:54:00.913586+00",
                )
            ],
        ),
    )
    """

    data: ProjectEntityResponse

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
import typing
from ...generated_types.types.relationships import Relationships
from .traversal_relationship_data import TraversalRelationshipData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TraversalPath(UniversalBaseModel):
    field: str
    entity: EntityDetails
    relationships: typing.Dict[Relationships, TraversalRelationshipData]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .ontology_risk_factors_filters import OntologyRiskFactorsFilters
import typing
from .ontology_risk_factor import OntologyRiskFactor
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyRiskFactorsResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.ontology import (
        GetOntologyRiskFactorsResponse,
        OntologyRiskFactor,
        OntologyRiskFactorsFilters,
    )

    GetOntologyRiskFactorsResponse(
        filters=OntologyRiskFactorsFilters(
            id=["psa_owner_of_ofac_fto_sanctioned"],
            risk_category=["sanctions"],
            level=["high"],
            risk_type=["network"],
            enabled=True,
            visible=True,
        ),
        data=[
            OntologyRiskFactor(
                id="psa_owner_of_ofac_fto_sanctioned",
                categories=["sanctions"],
                label="Owner of Foreign Terrorist Organisation (May Include 'PSA' Path)",
                description="This entity possibly owns (minority, majority, or wholly) a Foreign Terrorist Organization up to 3 hops away via direct shareholding relationships with 10% or more controlling interest, including beneficial owner, owner, shareholder, partner, subsidiary, or branch. Applicable to entities globally. This network risk path may include ‘Possibly the Same As’ (PSA) relationships—links between companies or persons that have closely matching attributes across datasets, but do not have enough shared information to definitively establish they are the same entity.",
                doc="This entity possibly owns (minority, majority, or wholly) a Foreign Terrorist Organization up to 3 hops away via direct shareholding relationships with 10% or more controlling interest, including beneficial owner, owner, shareholder, partner, subsidiary, or branch. Applicable to entities globally. This network risk path may include ‘Possibly the Same As’ (PSA) relationships—links between companies or persons that have closely matching attributes across datasets, but do not have enough shared information to definitively establish they are the same entity.",
                code=1168016564,
                level="high",
                risk_type="network",
                risk_viz="network",
                visible=True,
                enabled=True,
                type="integer",
                tg=True,
                do_not_render_metadata=["traversal_path"],
            )
        ],
        total_count=1234,
    )
    """

    filters: OntologyRiskFactorsFilters
    data: typing.List[OntologyRiskFactor]
    total_count: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Coordinates,
    EntitySearchResponse,
    FilterList,
    RecordSearchResponse,
    RiskFactor,
    SearchResults,
    SourceId,
)

__all__ = [
    "Coordinates",
    "EntitySearchResponse",
    "FilterList",
    "RecordSearchResponse",
    "RiskFactor",
    "SearchResults",
    "SourceId",
]



# This file was auto-generated by Fern from our API Definition.

from ...base_types.types.paginated_response import PaginatedResponse
from ...shared_types.types.entity_details import EntityDetails
from ...shared_types.types.entity_relationships import EntityRelationships
from ...shared_types.types.relationship_data import RelationshipData
import typing
from .search_results import SearchResults
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class EntitySearchResponse(PaginatedResponse):
    """
    OK

    Examples
    --------
    from sayari.base_types import QualifiedCount
    from sayari.search import Coordinates, EntitySearchResponse, SearchResults
    from sayari.shared_types import Identifier, RiskData, SourceCountInfo, Status

    EntitySearchResponse(
        offset=0,
        limit=1,
        size=QualifiedCount(
            count=41,
            qualifier="eq",
        ),
        next=True,
        data=[
            SearchResults(
                id="mGq1lpuqKssNWTjIokuPeA",
                label="VICTORIA BECKHAM LIMITED",
                degree=114,
                entity_url="/v1/entity/mGq1lpuqKssNWTjIokuPeA",
                pep=False,
                psa_id="65455301594691",
                psa_count=4,
                sanctioned=False,
                closed=False,
                company_type="LADIES FASHION",
                registration_date="Incorporated 2008-02-28",
                latest_status=Status(
                    status="active",
                    date="2023-08-29",
                ),
                trade_count={"sent": 82, "received": 2},
                type="company",
                identifiers=[
                    Identifier(
                        value="06517802",
                        type="uk_company_number",
                        label="Uk Company Number",
                    ),
                    Identifier(
                        value="6517802",
                        type="unknown",
                        label="Unknown",
                    ),
                    Identifier(
                        value="04781466",
                        type="ca_corporate_id_num",
                        label="Ca Corporate Id Num",
                    ),
                ],
                addresses=[
                    "202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
                    "Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
                    "Hammersmith Road, London, W6 7DN",
                ],
                countries=["GBR", "USA"],
                relationship_count={
                    "linked_to": 3,
                    "has_officer": 2,
                    "shareholder_of": 1,
                    "has_shareholder": 2,
                    "has_registered_agent": 5,
                    "has_director": 11,
                    "owner_of": 3,
                    "has_founder": 1,
                    "ships_to": 5,
                    "receives_from": 1,
                },
                source_count={
                    "2b618f1996252fe537a6d998ae14c9b2": SourceCountInfo(
                        count=1,
                        label="UK Corporate Registry Confirmation Statements",
                    ),
                    "2b788dbdf9194ed5a5c309386a6516b1": SourceCountInfo(
                        count=37,
                        label="UK HM Revenue & Customs Traders Database",
                    ),
                    "a447a7b622c4ead6e1caf94983dc2337": SourceCountInfo(
                        count=8,
                        label="USA California Secretary of State",
                    ),
                    "a7829d9c8999fcaa78af55886da9be06": SourceCountInfo(
                        count=43,
                        label="Turkey Imports & Exports (January 2024 - Present)",
                    ),
                    "ecdfb3f2ecc8c3797e77d5795a8066ef": SourceCountInfo(
                        count=40,
                        label="UK Corporate Registry",
                    ),
                    "e5de7b52cc88ef4cd1a10e201bdf46ee": SourceCountInfo(
                        count=41,
                        label="Vietnam Imports & Exports (January 2023 - Present)",
                    ),
                    "2a4fe9a14e332c8f9ded1f8a457c2b89": SourceCountInfo(
                        count=42,
                        label="UK Land Commercial and Corporate Ownership Data (CCOD)",
                    ),
                    "4ea8bac1bed868e1510ffd21842e9551": SourceCountInfo(
                        count=86,
                        label="UK Persons with Significant Control",
                    ),
                },
                risk={
                    "basel_aml": RiskData(
                        value=4.28,
                        metadata={"country": ["USA"]},
                        level="relevant",
                    ),
                    "cpi_score": RiskData(
                        value=69.0,
                        metadata={"country": ["USA"]},
                        level="relevant",
                    ),
                },
                user_attribute_counts={},
                user_attribute_count={},
                user_record_count=0,
                user_related_entities_count=0,
                user_relationship_count={},
                related_entities_count=114,
                attribute_counts={
                    "company_type": 3,
                    "name": 2,
                    "business_purpose": 4,
                    "identifier": 3,
                    "additional_information": 106,
                    "country": 7,
                    "status": 5,
                    "address": 6,
                },
                attribute_count={
                    "company_type": 3,
                    "name": 2,
                    "business_purpose": 4,
                    "identifier": 3,
                    "additional_information": 106,
                    "country": 7,
                    "status": 5,
                    "address": 6,
                },
                reference_id="ecdfb3f2ecc8c3797e77d5795a8066ef/06517802/1540252800000:4a34442eccf1622995130b194a5d50e7",
                logistics_entity=False,
                coordinates=[
                    Coordinates(
                        lat=51.49322001798694,
                        lng=-0.2220315859755715,
                        address="202 HAMMERSMITH ROAD , LONDON , , UNITED KINGDOM , W6 7DN , GB",
                    ),
                    Coordinates(
                        lat=51.47911101182882,
                        lng=-0.16811097048599777,
                        address="Unit 33, Ransomes Dock Business Centre, 35-37 Parkgate Road, London SW11 4NP",
                    ),
                    Coordinates(
                        lat=51.493835014595135,
                        lng=-0.21932487497451175,
                        address="Hammersmith Road, London, W6 7DN",
                    ),
                    Coordinates(
                        lat=53.06030545100003,
                        lng=-1.4104778399999418,
                        address="202 HAMMERSMITH ROAD UNITED KINGDOM",
                    ),
                    Coordinates(
                        address="202 HAMMERSMITH ROAD",
                    ),
                    Coordinates(
                        lat=51.490490045109766,
                        lng=-0.2455951217808129,
                        address="202 HAMMERSMITH ROAD BRITISH ISLES",
                    ),
                ],
                matches={
                    "name": [
                        "<em>VICTORIA</em> <em>BECKHAM</em> <em>LIMITED</em>",
                        "<em>BECKHAM</em> VENTURES <em>LIMITED</em>",
                        "<em>VICTORIA</em> <em>BECKHAM</em> LIMITED",
                        "<em>BECKHAM</em> VENTURES LIMITED",
                    ]
                },
            )
        ],
    )
    """

    offset: int
    next: bool
    data: typing.List[SearchResults]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .translation_context import TranslationContext
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TranslatedNameProperties(UniversalBaseModel):
    context: typing.Optional[TranslationContext] = pydantic.Field(default=None)
    """
    The type of translation
    """

    date: typing.Optional[str] = pydantic.Field(default=None)
    """
    as-of date of attribute
    """

    extra: typing.Optional[typing.Dict[str, typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    extra information of attribute
    """

    from_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    start date of attribute
    """

    original: typing.Optional[str] = pydantic.Field(default=None)
    """
    The original name
    """

    to_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    end date of attribute
    """

    value: str = pydantic.Field()
    """
    The name, as text
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Address,
    AttributeType,
    AttributeTypesResponse,
    AttributeValues,
    AttributesResponse,
    BusinessPurpose,
    CountType,
    CreateResolvedProjectEntityRequest,
    FacetBucket,
    FacetsResponse,
    FieldMatchQuality,
    GroupedAttribute,
    GroupedAttributeValue,
    Location,
    MatchProfileEnum,
    ProductBucket,
    ProductCount,
    ProductMapping,
    ProjectEntitiesCustomFieldFilter,
    ProjectEntitiesExactFilter,
    ProjectEntitiesFilter,
    ProjectEntitiesFuzzyFilter,
    ProjectEntitiesResponse,
    ProjectEntityExistsResponseData,
    ProjectEntityIdResponse,
    ProjectEntityMatchExplanation,
    ProjectEntityMatchResponse,
    ProjectEntityResponse,
    ProjectEntityRiskChangesResponse,
    ProjectEntityRiskChangesResponseData,
    ProjectEntityRiskSummaryData,
    ProjectEntityRiskSummaryFilters,
    ProjectEntityRiskSummaryNetworkPath,
    ProjectEntityRiskSummaryResponse,
    ProjectEntityRiskSummaryResponseFilters,
    ProjectEntityRiskSummaryRiskFactor,
    ProjectEntitySupplyChainSummaryResponse,
    ProjectEntitySupplyChainSummaryResponseData,
    ProjectEntitySupplyChainUpstream,
    ProjectRiskCategory,
    ProjectRiskChange,
    ProjectRiskChangesResponse,
    ProjectRiskChangesResponseData,
    ProjectRiskFactor,
    ResolutionAttributes,
    ResolutionProfile,
    RiskCategoriesSummary,
    RiskChangeFactor,
    RiskChangeFactorChangeType,
    RiskChangeFilters,
    SaveProjectEntityBody,
    ShareInformation,
    SingleProjectEntityResponse,
    SortOrder,
    SourceField,
    SpecialFacetBucket,
    SpecialFacetsResponse,
    StringOrNumber,
    TagResponse,
    TradeCounts,
    Translation,
    UpdateEntityTagsResponse,
    UpdateProjectEntityTagsBody,
    UpstreamCount,
    UpstreamInfo,
)

__all__ = [
    "Address",
    "AttributeType",
    "AttributeTypesResponse",
    "AttributeValues",
    "AttributesResponse",
    "BusinessPurpose",
    "CountType",
    "CreateResolvedProjectEntityRequest",
    "FacetBucket",
    "FacetsResponse",
    "FieldMatchQuality",
    "GroupedAttribute",
    "GroupedAttributeValue",
    "Location",
    "MatchProfileEnum",
    "ProductBucket",
    "ProductCount",
    "ProductMapping",
    "ProjectEntitiesCustomFieldFilter",
    "ProjectEntitiesExactFilter",
    "ProjectEntitiesFilter",
    "ProjectEntitiesFuzzyFilter",
    "ProjectEntitiesResponse",
    "ProjectEntityExistsResponseData",
    "ProjectEntityIdResponse",
    "ProjectEntityMatchExplanation",
    "ProjectEntityMatchResponse",
    "ProjectEntityResponse",
    "ProjectEntityRiskChangesResponse",
    "ProjectEntityRiskChangesResponseData",
    "ProjectEntityRiskSummaryData",
    "ProjectEntityRiskSummaryFilters",
    "ProjectEntityRiskSummaryNetworkPath",
    "ProjectEntityRiskSummaryResponse",
    "ProjectEntityRiskSummaryResponseFilters",
    "ProjectEntityRiskSummaryRiskFactor",
    "ProjectEntitySupplyChainSummaryResponse",
    "ProjectEntitySupplyChainSummaryResponseData",
    "ProjectEntitySupplyChainUpstream",
    "ProjectRiskCategory",
    "ProjectRiskChange",
    "ProjectRiskChangesResponse",
    "ProjectRiskChangesResponseData",
    "ProjectRiskFactor",
    "ResolutionAttributes",
    "ResolutionProfile",
    "RiskCategoriesSummary",
    "RiskChangeFactor",
    "RiskChangeFactorChangeType",
    "RiskChangeFilters",
    "SaveProjectEntityBody",
    "ShareInformation",
    "SingleProjectEntityResponse",
    "SortOrder",
    "SourceField",
    "SpecialFacetBucket",
    "SpecialFacetsResponse",
    "StringOrNumber",
    "TagResponse",
    "TradeCounts",
    "Translation",
    "UpdateEntityTagsResponse",
    "UpdateProjectEntityTagsBody",
    "UpstreamCount",
    "UpstreamInfo",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .string_or_number import StringOrNumber
from ...shared_types.types.risk_level import RiskLevel
import typing
from .project_risk_category import ProjectRiskCategory
from .project_entity_risk_summary_network_path import ProjectEntityRiskSummaryNetworkPath
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ProjectEntityRiskSummaryRiskFactor(UniversalBaseModel):
    id: str
    label: str
    value: StringOrNumber
    level: RiskLevel
    risk_categories: typing.List[ProjectRiskCategory]
    source_entity_ids: typing.List[str]
    network_paths: typing.List[typing.List[ProjectEntityRiskSummaryNetworkPath]]
    metadata: typing.List[typing.Dict[str, typing.List[StringOrNumber]]]
    risk_intelligence: typing.List[typing.Dict[str, StringOrNumber]]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .create_project_entity_supply_chain_snapshot_request import CreateProjectEntitySupplyChainSnapshotRequest
from .create_project_entity_supply_chain_snapshot_response import CreateProjectEntitySupplyChainSnapshotResponse
from .project_entity_supply_chain_snapshot_by_id_response import ProjectEntitySupplyChainSnapshotByIdResponse
from .project_entity_supply_chain_snapshot_data import ProjectEntitySupplyChainSnapshotData
from .project_entity_supply_chain_snapshot_detail_data import ProjectEntitySupplyChainSnapshotDetailData
from .project_entity_supply_chain_snapshots_response import ProjectEntitySupplyChainSnapshotsResponse
from .supply_chain_edge import SupplyChainEdge
from .supply_chain_node import SupplyChainNode

__all__ = [
    "CreateProjectEntitySupplyChainSnapshotRequest",
    "CreateProjectEntitySupplyChainSnapshotResponse",
    "ProjectEntitySupplyChainSnapshotByIdResponse",
    "ProjectEntitySupplyChainSnapshotData",
    "ProjectEntitySupplyChainSnapshotDetailData",
    "ProjectEntitySupplyChainSnapshotsResponse",
    "SupplyChainEdge",
    "SupplyChainNode",
]



# This file was auto-generated by Fern from our API Definition.

import typing

MeasurementType = typing.Union[
    typing.Literal["built_area", "gross_weight", "land_area", "net_weight", "quantity"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    CreateProjectEntityAttributeRequest,
    CreateProjectEntityAttributeResponse,
    CreateProjectEntityAttributeResponseData,
    ProjectEntityAttribute,
    ProjectEntityAttributeValue,
    ProjectEntityAttributesResponse,
    UpdateProjectEntityAttributeRequest,
    UpdateProjectEntityAttributeResponse,
    UpdateProjectEntityAttributeResponseData,
)

__all__ = [
    "CreateProjectEntityAttributeRequest",
    "CreateProjectEntityAttributeResponse",
    "CreateProjectEntityAttributeResponseData",
    "ProjectEntityAttribute",
    "ProjectEntityAttributeValue",
    "ProjectEntityAttributesResponse",
    "UpdateProjectEntityAttributeRequest",
    "UpdateProjectEntityAttributeResponse",
    "UpdateProjectEntityAttributeResponseData",
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from .ontology_attribute import OntologyAttribute
from .ontology_country import OntologyCountry
from .ontology_currency import OntologyCurrency
from .ontology_entity_type import OntologyEntityType
from .ontology_enum import OntologyEnum
from .ontology_identifier import OntologyIdentifier
from .ontology_language import OntologyLanguage
from .ontology_region import OntologyRegion
from .ontology_relationship import OntologyRelationship
from .ontology_risk_factor import OntologyRiskFactor
from .ontology_source import OntologySource
from .ontology_source_type import OntologySourceType
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class GetOntologyResponseData(UniversalBaseModel):
    attributes: typing.List[OntologyAttribute]
    countries: typing.List[OntologyCountry]
    currencies: typing.List[OntologyCurrency]
    entity_types: typing.List[OntologyEntityType]
    enums: typing.List[OntologyEnum]
    identifiers: typing.List[OntologyIdentifier]
    languages: typing.List[OntologyLanguage]
    regions: typing.List[OntologyRegion]
    relationships: typing.List[OntologyRelationship]
    risk_factors: typing.List[OntologyRiskFactor]
    sources: typing.List[OntologySource]
    source_types: typing.List[OntologySourceType]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from ..core.client_wrapper import SyncClientWrapper
from ..core.request_options import RequestOptions
from .types.project_entity_supply_chain_snapshots_response import ProjectEntitySupplyChainSnapshotsResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.pydantic_utilities import parse_obj_as
from ..shared_errors.errors.bad_request import BadRequest
from ..shared_errors.types.bad_request_response import BadRequestResponse
from ..shared_errors.errors.unauthorized import Unauthorized
from ..shared_errors.types.unauthorized_response import UnauthorizedResponse
from ..shared_errors.errors.not_found import NotFound
from ..shared_errors.types.not_found_response import NotFoundResponse
from ..shared_errors.errors.method_not_allowed import MethodNotAllowed
from ..shared_errors.types.method_not_allowed_response import MethodNotAllowedResponse
from ..shared_errors.errors.rate_limit_exceeded import RateLimitExceeded
from ..shared_errors.types.rate_limit_response import RateLimitResponse
from ..shared_errors.errors.internal_server_error import InternalServerError
from ..shared_errors.types.internal_server_error_response import InternalServerErrorResponse
from json.decoder import JSONDecodeError
from ..core.api_error import ApiError
from .types.project_entity_supply_chain_snapshot_by_id_response import ProjectEntitySupplyChainSnapshotByIdResponse
from .types.create_project_entity_supply_chain_snapshot_request import CreateProjectEntitySupplyChainSnapshotRequest
from .types.create_project_entity_supply_chain_snapshot_response import CreateProjectEntitySupplyChainSnapshotResponse
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.client_wrapper import AsyncClientWrapper

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ProjectEntitySupplyChainSnapshotsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def get_project_entity_supply_chain_snapshots(
        self, project_id: str, project_entity_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ProjectEntitySupplyChainSnapshotsResponse:
        """
        Retrieves all supply chain snapshots for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectEntitySupplyChainSnapshotsResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.project_entity_supply_chain_snapshots.get_project_entity_supply_chain_snapshots(
            project_id="V03eYM",
            project_entity_id="BG72YW",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectEntitySupplyChainSnapshotsResponse,
                    parse_obj_as(
                        type_=ProjectEntitySupplyChainSnapshotsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def get_project_entity_supply_chain_snapshot_by_id(
        self,
        project_id: str,
        project_entity_id: str,
        snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectEntitySupplyChainSnapshotByIdResponse:
        """
        Retrieves a specific supply chain snapshot by ID for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        snapshot_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectEntitySupplyChainSnapshotByIdResponse

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.project_entity_supply_chain_snapshots.get_project_entity_supply_chain_snapshot_by_id(
            project_id="V03eYM",
            project_entity_id="BG72YW",
            snapshot_id="sN4p2K",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots/{jsonable_encoder(snapshot_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectEntitySupplyChainSnapshotByIdResponse,
                    parse_obj_as(
                        type_=ProjectEntitySupplyChainSnapshotByIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def create_project_entity_supply_chain_snapshot(
        self,
        project_id: str,
        project_entity_id: str,
        *,
        request: CreateProjectEntitySupplyChainSnapshotRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateProjectEntitySupplyChainSnapshotResponse:
        """
        Creates a new supply chain snapshot for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        request : CreateProjectEntitySupplyChainSnapshotRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateProjectEntitySupplyChainSnapshotResponse

        Examples
        --------
        from sayari import Sayari
        from sayari.project_entity_supply_chain_snapshots import (
            CreateProjectEntitySupplyChainSnapshotRequest,
        )

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.project_entity_supply_chain_snapshots.create_project_entity_supply_chain_snapshot(
            project_id="V03eYM",
            project_entity_id="BG72YW",
            request=CreateProjectEntitySupplyChainSnapshotRequest(
                label="Q1 2024 Supply Chain Analysis",
            ),
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots",
            method="POST",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=CreateProjectEntitySupplyChainSnapshotRequest, direction="write"
            ),
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    CreateProjectEntitySupplyChainSnapshotResponse,
                    parse_obj_as(
                        type_=CreateProjectEntitySupplyChainSnapshotResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    def delete_project_entity_supply_chain_snapshot_by_id(
        self,
        project_id: str,
        project_entity_id: str,
        snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Deletes a specific supply chain snapshot by ID for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        snapshot_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from sayari import Sayari

        client = Sayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )
        client.project_entity_supply_chain_snapshots.delete_project_entity_supply_chain_snapshot_by_id(
            project_id="project_id",
            project_entity_id="project_entity_id",
            snapshot_id="snapshot_id",
        )
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots/{jsonable_encoder(snapshot_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)


class AsyncProjectEntitySupplyChainSnapshotsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def get_project_entity_supply_chain_snapshots(
        self, project_id: str, project_entity_id: str, *, request_options: typing.Optional[RequestOptions] = None
    ) -> ProjectEntitySupplyChainSnapshotsResponse:
        """
        Retrieves all supply chain snapshots for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectEntitySupplyChainSnapshotsResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.project_entity_supply_chain_snapshots.get_project_entity_supply_chain_snapshots(
                project_id="V03eYM",
                project_entity_id="BG72YW",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectEntitySupplyChainSnapshotsResponse,
                    parse_obj_as(
                        type_=ProjectEntitySupplyChainSnapshotsResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def get_project_entity_supply_chain_snapshot_by_id(
        self,
        project_id: str,
        project_entity_id: str,
        snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectEntitySupplyChainSnapshotByIdResponse:
        """
        Retrieves a specific supply chain snapshot by ID for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        snapshot_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectEntitySupplyChainSnapshotByIdResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.project_entity_supply_chain_snapshots.get_project_entity_supply_chain_snapshot_by_id(
                project_id="V03eYM",
                project_entity_id="BG72YW",
                snapshot_id="sN4p2K",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots/{jsonable_encoder(snapshot_id)}",
            method="GET",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    ProjectEntitySupplyChainSnapshotByIdResponse,
                    parse_obj_as(
                        type_=ProjectEntitySupplyChainSnapshotByIdResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def create_project_entity_supply_chain_snapshot(
        self,
        project_id: str,
        project_entity_id: str,
        *,
        request: CreateProjectEntitySupplyChainSnapshotRequest,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> CreateProjectEntitySupplyChainSnapshotResponse:
        """
        Creates a new supply chain snapshot for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        request : CreateProjectEntitySupplyChainSnapshotRequest

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        CreateProjectEntitySupplyChainSnapshotResponse

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari
        from sayari.project_entity_supply_chain_snapshots import (
            CreateProjectEntitySupplyChainSnapshotRequest,
        )

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.project_entity_supply_chain_snapshots.create_project_entity_supply_chain_snapshot(
                project_id="V03eYM",
                project_entity_id="BG72YW",
                request=CreateProjectEntitySupplyChainSnapshotRequest(
                    label="Q1 2024 Supply Chain Analysis",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots",
            method="POST",
            json=convert_and_respect_annotation_metadata(
                object_=request, annotation=CreateProjectEntitySupplyChainSnapshotRequest, direction="write"
            ),
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return typing.cast(
                    CreateProjectEntitySupplyChainSnapshotResponse,
                    parse_obj_as(
                        type_=CreateProjectEntitySupplyChainSnapshotResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)

    async def delete_project_entity_supply_chain_snapshot_by_id(
        self,
        project_id: str,
        project_entity_id: str,
        snapshot_id: str,
        *,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> None:
        """
        Deletes a specific supply chain snapshot by ID for a project entity.

        Parameters
        ----------
        project_id : str

        project_entity_id : str

        snapshot_id : str

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from sayari import AsyncSayari

        client = AsyncSayari(
            client_id="YOUR_CLIENT_ID",
            client_secret="YOUR_CLIENT_SECRET",
        )


        async def main() -> None:
            await client.project_entity_supply_chain_snapshots.delete_project_entity_supply_chain_snapshot_by_id(
                project_id="project_id",
                project_entity_id="project_entity_id",
                snapshot_id="snapshot_id",
            )


        asyncio.run(main())
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v1/projects/{jsonable_encoder(project_id)}/entities/{jsonable_encoder(project_entity_id)}/supply_chain/snapshots/{jsonable_encoder(snapshot_id)}",
            method="DELETE",
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                return
            if _response.status_code == 400:
                raise BadRequest(
                    typing.cast(
                        BadRequestResponse,
                        parse_obj_as(
                            type_=BadRequestResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 401:
                raise Unauthorized(
                    typing.cast(
                        UnauthorizedResponse,
                        parse_obj_as(
                            type_=UnauthorizedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 404:
                raise NotFound(
                    typing.cast(
                        NotFoundResponse,
                        parse_obj_as(
                            type_=NotFoundResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 405:
                raise MethodNotAllowed(
                    typing.cast(
                        MethodNotAllowedResponse,
                        parse_obj_as(
                            type_=MethodNotAllowedResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 429:
                raise RateLimitExceeded(
                    typing.cast(
                        RateLimitResponse,
                        parse_obj_as(
                            type_=RateLimitResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            if _response.status_code == 500:
                raise InternalServerError(
                    typing.cast(
                        InternalServerErrorResponse,
                        parse_obj_as(
                            type_=InternalServerErrorResponse,  # type: ignore
                            object_=_response.json(),
                        ),
                    )
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, body=_response.text)
        raise ApiError(status_code=_response.status_code, body=_response_json)



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
import typing
from ...generated_types.types.risk import Risk
import pydantic
import typing_extensions
from ...core.serialization import FieldMetadata
from ...generated_types.types.country import Country
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class TradeTraversalFilters(UniversalBaseModel):
    risk_factors: typing.Optional[typing.List[Risk]] = pydantic.Field(default=None)
    """
    Risk leaf node filter. Only return supply chains that end with a supplier that has 1+ of the specified risk factors.
    """

    not_risk: typing_extensions.Annotated[typing.Optional[typing.List[Risk]], FieldMetadata(alias="-risk_factors")] = (
        pydantic.Field(default=None)
    )
    """
    Risk leaf node filter. Only return supply chains that end with a supplier that has none of the specified risk factors.
    """

    countries: typing.Optional[typing.List[Country]] = pydantic.Field(default=None)
    """
    Country leaf node filter. Only return supply chains that end with a supplier in 1+ of the specified countries.
    """

    not_countries: typing_extensions.Annotated[
        typing.Optional[typing.List[Country]], FieldMetadata(alias="-countries")
    ] = pydantic.Field(default=None)
    """
    Country leaf node filter. Only return supply chains that end with a supplier in none of the specified countries.
    """

    product: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Product root edge filter. Only return supply chains that start with an edge that has 1+ of the specified HS codes.
    """

    not_product: typing_extensions.Annotated[typing.Optional[typing.List[str]], FieldMetadata(alias="-product")] = (
        pydantic.Field(default=None)
    )
    """
    Product root edge filter. Only return supply chains that start with an edge that has none of the specified HS codes.
    """

    component: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Component edge filter. Only return supply chains that contain at least one edge with 1+ of the specified HS codes.
    """

    not_component: typing_extensions.Annotated[typing.Optional[typing.List[str]], FieldMetadata(alias="-component")] = (
        pydantic.Field(default=None)
    )
    """
    Component edge filter. Only return supply chains that contain no edges with any of the specified HS codes.
    """

    min_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Minimum date edge filter in <YYYY-MM-DD> format. Only return supply chains with edge dates that are greater than or equal to this date.
    """

    max_date: typing.Optional[str] = pydantic.Field(default=None)
    """
    Maximum date edge filter in <YYYY-MM-DD> format. Only return supply chains with edge dates that are less than or equal to this date.
    """

    max_depth: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum depth of the traversal, from 1 to 4 inclusive. Default is 4. Reduce if query is timing out.
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    The maximum number of results to return. Default is no limit.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .project_entity_supply_chain_snapshot_detail_data import ProjectEntitySupplyChainSnapshotDetailData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ProjectEntitySupplyChainSnapshotByIdResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity_supply_chain_snapshots import (
        ProjectEntitySupplyChainSnapshotByIdResponse,
        ProjectEntitySupplyChainSnapshotDetailData,
        SupplyChainEdge,
        SupplyChainNode,
    )

    ProjectEntitySupplyChainSnapshotByIdResponse(
        data=ProjectEntitySupplyChainSnapshotDetailData(
            snapshot_id="nK9mP2",
            label="Production Supply Chain Analysis",
            release_tag="20250115143000_prod",
            partial_results=True,
            explored_count=15,
            created_at="2025-01-15 14:30:00.12345+00",
            updated_at="2025-01-15 14:30:00.12345+00",
            nodes=[
                SupplyChainNode(
                    id="xG8wYP",
                    entity_id="oSlRbVMw4JdQ_R0nTd7yaQ",
                    label="TechCorp Inc",
                    type="company",
                    risk_factors=[
                        "export_controls",
                        "former_wro_entity",
                        "export_to_soe",
                    ],
                    countries=["USA", "CHN"],
                ),
                SupplyChainNode(
                    id="6GaxYn",
                    entity_id="rSoUePz7MgU_U3qWg0bdT",
                    label="Trade Partners Ltd",
                    type="company",
                    risk_factors=[
                        "export_controls",
                        "former_wro_entity",
                        "export_to_soe",
                    ],
                    countries=["RUS", "IRN"],
                ),
                SupplyChainNode(
                    id="JGlwYl",
                    entity_id="sTpVfQa8NhV_V4rXh1ceU",
                    label="International Logistics",
                    type="company",
                    risk_factors=["export_to_soe"],
                    countries=["GBR", "NLD"],
                ),
            ],
            edges=[
                SupplyChainEdge(
                    id="xG8wYP",
                    src_id="6GaxYn",
                    dst_id="xG8wYP",
                    departure_countries=["AFG"],
                    arrival_countries=["AFG", "AGO"],
                    hs_code="0303",
                    min_date="51969-08-29T00:00:00+00:00",
                    max_date="52971-09-25T00:00:00+00:00",
                ),
                SupplyChainEdge(
                    id="6GaxYn",
                    src_id="6GaxYn",
                    dst_id="JGlwYl",
                    departure_countries=["AFG"],
                    arrival_countries=["AFG", "AGO"],
                    hs_code="0304",
                    min_date="51969-08-29T00:00:00+00:00",
                    max_date="52971-09-25T00:00:00+00:00",
                ),
                SupplyChainEdge(
                    id="V03eYM",
                    src_id="xG8wYP",
                    dst_id="JGlwYl",
                    departure_countries=["USA", "CHN"],
                    arrival_countries=["GBR", "NLD"],
                    hs_code="0303",
                    min_date="51969-08-29T00:00:00+00:00",
                    max_date="52971-09-25T00:00:00+00:00",
                ),
            ],
        ),
    )
    """

    data: ProjectEntitySupplyChainSnapshotDetailData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from ...generated_types.types.attributes import Attributes
from ...generated_types.types.relationships import Relationships

OntologyEntityTypeField = typing.Union[Attributes, Relationships]



# This file was auto-generated by Fern from our API Definition.

import typing

AddressType = typing.Union[
    typing.Literal[
        "arrival",
        "business",
        "departure",
        "mailing",
        "operations",
        "physical",
        "place_of_birth",
        "receiver_address",
        "registered",
        "shipper_address",
        "transit",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...supply_chain.types.trade_traversal_filters import TradeTraversalFilters
from .project_entity_supply_chain_summary_response_data import ProjectEntitySupplyChainSummaryResponseData
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class ProjectEntitySupplyChainSummaryResponse(UniversalBaseModel):
    """
    Examples
    --------
    from sayari.project_entity import (
        ProjectEntitySupplyChainSummaryResponse,
        ProjectEntitySupplyChainSummaryResponseData,
        ProjectEntitySupplyChainUpstream,
        RiskCategoriesSummary,
    )
    from sayari.supply_chain import TradeTraversalFilters

    ProjectEntitySupplyChainSummaryResponse(
        filters=TradeTraversalFilters(
            min_date="2023-03-15",
            product=["8536", "8544", "4016"],
            risk_factors=[
                "forced_labor_xinjiang_name",
                "forced_labor_xinjiang_uflpa",
                "forced_labor_uflpa_origin_direct",
                "exports_russian_gold",
                "export_to_sanctioned",
            ],
        ),
        data=ProjectEntitySupplyChainSummaryResponseData(
            project_id="8YMJNG",
            project_entity_id="Gyvp8E",
            upstream=ProjectEntitySupplyChainUpstream(
                components=["8536", "8544", "4016"],
                countries=["JPN", "IND", "VNM", "PHL"],
                risk_categories=[
                    RiskCategoriesSummary(
                        id="forced_labor",
                        label="Forced labor",
                        risk_factors=[
                            "forced_labor_xinjiang_name",
                            "forced_labor_xinjiang_uflpa",
                            "forced_labor_uflpa_origin_direct",
                        ],
                    ),
                    RiskCategoriesSummary(
                        id="export_controls",
                        label="Export controls",
                        risk_factors=[
                            "exports_russian_gold",
                            "export_to_sanctioned",
                        ],
                    ),
                ],
            ),
        ),
    )
    """

    filters: TradeTraversalFilters
    data: ProjectEntitySupplyChainSummaryResponseData

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

Risk = typing.Union[
    typing.Literal[
        "aspi_uyghur_forced_labor_report_entity",
        "aspi_uyghur_forced_labor_report_entity_adjacent",
        "basel_aml",
        "bis_addresses_high_diversion_risk",
        "bis_boycott_requester_list",
        "chinese_soe_adjacent",
        "chinese_state_owned",
        "cmic_entity",
        "cmic_entity_50_percent_rule",
        "controlled_by_aus_sanctioned",
        "controlled_by_eu_sanctioned",
        "controlled_by_jpn_sanctioned",
        "controlled_by_ofac_fto_sanctioned",
        "controlled_by_ofac_illicit_drugs_eo14059_sanctioned",
        "controlled_by_ofac_sdgt_sanctioned",
        "controlled_by_ofac_sdn",
        "controlled_by_ofac_sdnt_sanctioned",
        "controlled_by_ofac_sdntk_sanctioned",
        "controlled_by_uk_sanctioned",
        "controlled_by_ukr_sanctioned",
        "controlled_by_un_sanctioned",
        "cpi_score",
        "entity_licensed_with_fsb_rf",
        "esg_score_high",
        "esg_score_medium",
        "esg_score_very_high",
        "eu_50_percent_rule",
        "eu_high_risk_third",
        "eu_minority_ownership",
        "eu_sanctioned",
        "export_controls",
        "export_controls_adjacent",
        "export_controls_bis_entity",
        "export_controls_bis_entity_50_percent_rule",
        "export_controls_bis_meu",
        "export_controls_bis_meu_50_percent_rule",
        "export_controls_section_1260h",
        "export_controls_section_1260h_50_percent_rule",
        "export_controls_unverified_list",
        "export_controls_unverified_list_50_percent_rule",
        "export_to_chinese_soe",
        "export_to_sanctioned",
        "export_to_soe",
        "exports_bis_high_priority_items_critical_components_direct",
        "exports_bis_high_priority_items_critical_components_indirect",
        "exports_bis_high_priority_items_direct",
        "exports_bis_high_priority_items_indirect",
        "exports_conflict_minerals",
        "exports_eudr_shipment_cattle",
        "exports_eudr_shipment_cocoa",
        "exports_eudr_shipment_coffee",
        "exports_eudr_shipment_palm_oil",
        "exports_eudr_shipment_rubber",
        "exports_eudr_shipment_soya",
        "exports_eudr_shipment_wood",
        "exports_ilab_child_labor",
        "exports_ilab_forced_labor",
        "exports_russian_coal",
        "exports_russian_gold",
        "exports_russian_important_good",
        "exports_russian_oil",
        "exports_to_bis_addresses_high_diversion_risk",
        "exports_to_entity_licensed_with_fsb_rf",
        "exports_to_jpn_meti_end_user_entity",
        "exports_to_jpn_mofa_export_ban_entity",
        "exports_to_sanctioned_arg_repet_jus_entity",
        "exports_to_sanctioned_aus_dfat_entity",
        "exports_to_sanctioned_bel_fpsf_entity",
        "exports_to_sanctioned_can_gac_entity",
        "exports_to_sanctioned_che_seco_entity",
        "exports_to_sanctioned_cze_mof_entity",
        "exports_to_sanctioned_eu_dg_fisma_ec_entity",
        "exports_to_sanctioned_eu_ec_regulation_833_2014_entity",
        "exports_to_sanctioned_eu_ec_sanctions_map_entity",
        "exports_to_sanctioned_eu_sanctions_entity",
        "exports_to_sanctioned_fra_dgt_mefids_entity",
        "exports_to_sanctioned_gbr_fcdo_entity",
        "exports_to_sanctioned_gbr_hmt_ofsi_entity",
        "exports_to_sanctioned_isr_mod_nbctf_entity",
        "exports_to_sanctioned_jpn_mof_entity",
        "exports_to_sanctioned_ltu_mi_entity",
        "exports_to_sanctioned_lva_fis_entity",
        "exports_to_sanctioned_mys_moha_entity",
        "exports_to_sanctioned_nld_mofa_entity",
        "exports_to_sanctioned_nzl_mfat_rus_entity",
        "exports_to_sanctioned_pol_mia_entity",
        "exports_to_sanctioned_sgp_agc_entity",
        "exports_to_sanctioned_ukr_nsdc_entity",
        "exports_to_sanctioned_ukr_sfms_entity",
        "exports_to_sanctioned_un_sc_entity",
        "exports_to_sanctioned_usa_ofac_non_sdn_entity",
        "exports_to_sanctioned_usa_ofac_sdn_entity",
        "exports_to_sanctioned_xxx_ebrd_entity",
        "exports_to_sanctioned_xxx_iabd_entity",
        "exports_to_usa_aeca_debarred_entity",
        "exports_to_usa_bis_denied_persons_entity",
        "exports_to_usa_bis_entity",
        "exports_to_usa_bis_meu_entity",
        "exports_to_usa_bis_unverified_entity",
        "exports_to_usa_isn_entity",
        "exports_to_usa_section_1260h_entity",
        "forced_labor_aspi_origin_direct",
        "forced_labor_aspi_origin_subtier",
        "forced_labor_aspi_origin_subtier_product_blueprint",
        "forced_labor_china_keywords",
        "forced_labor_sheffield_hallam_university_reports_origin_direct",
        "forced_labor_sheffield_hallam_university_reports_origin_subtier",
        "forced_labor_sheffield_hallam_university_reports_origin_subtier_product_blueprint",
        "forced_labor_uflpa_origin_direct",
        "forced_labor_uflpa_origin_subtier",
        "forced_labor_uflpa_origin_subtier_product_blueprint",
        "forced_labor_wro_origin_direct",
        "forced_labor_wro_origin_subtier",
        "forced_labor_wro_origin_subtier_product_blueprint",
        "forced_labor_xinjiang_contractors",
        "forced_labor_xinjiang_cotton_entity",
        "forced_labor_xinjiang_geospatial",
        "forced_labor_xinjiang_name",
        "forced_labor_xinjiang_operations",
        "forced_labor_xinjiang_origin_direct",
        "forced_labor_xinjiang_origin_subtier",
        "forced_labor_xinjiang_origin_subtier_product_blueprint",
        "forced_labor_xinjiang_registration",
        "forced_labor_xinjiang_uflpa",
        "forced_labor_xinjiang_uflpa_adjacent",
        "former_soe",
        "former_wro_entity",
        "formerly_sanctioned",
        "formerly_sanctioned_arg_repet_jus",
        "formerly_sanctioned_aus_dfat",
        "formerly_sanctioned_bel_fpsf",
        "formerly_sanctioned_can_gac",
        "formerly_sanctioned_che_seco",
        "formerly_sanctioned_cze_mof",
        "formerly_sanctioned_eu_dg_fisma_ec",
        "formerly_sanctioned_eu_ec_regulation_833_2014",
        "formerly_sanctioned_eu_ec_sanctions_map",
        "formerly_sanctioned_eu_sanctions",
        "formerly_sanctioned_fra_dgt_mefids",
        "formerly_sanctioned_gbr_fcdo",
        "formerly_sanctioned_gbr_hmt_ofsi",
        "formerly_sanctioned_isr_mod_nbctf",
        "formerly_sanctioned_jpn_mof",
        "formerly_sanctioned_ltu_mi",
        "formerly_sanctioned_lva_fis",
        "formerly_sanctioned_mys_moha",
        "formerly_sanctioned_nld_mofa",
        "formerly_sanctioned_nzl_mfat_rus",
        "formerly_sanctioned_pol_mia",
        "formerly_sanctioned_sgp_agc",
        "formerly_sanctioned_ukr_nsdc",
        "formerly_sanctioned_ukr_sfms",
        "formerly_sanctioned_un_sc",
        "formerly_sanctioned_usa_ofac_non_sdn",
        "formerly_sanctioned_usa_ofac_sdn",
        "formerly_sanctioned_xxx_ebrd",
        "formerly_sanctioned_xxx_iabd",
        "imports_bis_high_priority_items",
        "imports_bis_high_priority_items_critical_components",
        "imports_conflict_minerals",
        "imports_eudr_shipment_cattle",
        "imports_eudr_shipment_cocoa",
        "imports_eudr_shipment_coffee",
        "imports_eudr_shipment_palm_oil",
        "imports_eudr_shipment_rubber",
        "imports_eudr_shipment_soya",
        "imports_eudr_shipment_wood",
        "imports_from_bis_addresses_high_diversion_risk",
        "imports_ilab_child_labor",
        "imports_ilab_forced_labor",
        "imports_ndaa_889_telecom_equipment",
        "imports_russian_coal",
        "imports_russian_gold",
        "imports_russian_important_good",
        "imports_russian_oil",
        "jpn_meti_end_user",
        "jpn_mofa_export_ban",
        "law_enforcement_action",
        "meu_list_contractors",
        "military_civil_fusion",
        "military_civil_fusion_50_percent_rule",
        "military_end_use_china_keywords",
        "ndaa_889_covered_entities",
        "ofac_50_percent_rule",
        "ofac_fto_sanctioned",
        "ofac_illicit_drugs_eo14059_sanctioned",
        "ofac_minority_ownership",
        "ofac_sdgt_sanctioned",
        "ofac_sdn",
        "ofac_sdn_mex_dto_sanctioned",
        "ofac_sdn_mex_dto_sanctioned_adjacent",
        "ofac_sdnt_sanctioned",
        "ofac_sdntk_sanctioned",
        "owned_by_aspi_forced_labor_entity",
        "owned_by_bis_meu_entity",
        "owned_by_chinese_soe",
        "owned_by_cmic_entity",
        "owned_by_entity_in_export_controls",
        "owned_by_forced_labor_xinjiang_uflpa",
        "owned_by_jpn_meti_end_user_entity",
        "owned_by_jpn_mofa_export_ban_entity",
        "owned_by_military_civil_fusion",
        "owned_by_ofac_fto_sanctioned",
        "owned_by_ofac_illicit_drugs_eo14059_sanctioned",
        "owned_by_ofac_sdgt_sanctioned",
        "owned_by_ofac_sdn_mex_dto_sanctioned",
        "owned_by_ofac_sdnt_sanctioned",
        "owned_by_ofac_sdntk_sanctioned",
        "owned_by_sanctioned_arg_repet_jus_entity",
        "owned_by_sanctioned_aus_dfat_entity",
        "owned_by_sanctioned_bel_fpsf_entity",
        "owned_by_sanctioned_can_gac_entity",
        "owned_by_sanctioned_che_seco_entity",
        "owned_by_sanctioned_cze_mof_entity",
        "owned_by_sanctioned_entity",
        "owned_by_sanctioned_eu_dg_fisma_ec_entity",
        "owned_by_sanctioned_eu_ec_regulation_833_2014_entity",
        "owned_by_sanctioned_eu_ec_sanctions_map_entity",
        "owned_by_sanctioned_eu_sanctions_entity",
        "owned_by_sanctioned_fra_dgt_mefids_entity",
        "owned_by_sanctioned_gbr_fcdo_entity",
        "owned_by_sanctioned_gbr_hmt_ofsi_entity",
        "owned_by_sanctioned_isr_mod_nbctf_entity",
        "owned_by_sanctioned_jpn_mof_entity",
        "owned_by_sanctioned_ltu_mi_entity",
        "owned_by_sanctioned_lva_fis_entity",
        "owned_by_sanctioned_mys_moha_entity",
        "owned_by_sanctioned_nld_mofa_entity",
        "owned_by_sanctioned_nzl_mfat_rus_entity",
        "owned_by_sanctioned_pol_mia_entity",
        "owned_by_sanctioned_sgp_agc_entity",
        "owned_by_sanctioned_ukr_nsdc_entity",
        "owned_by_sanctioned_ukr_sfms_entity",
        "owned_by_sanctioned_un_sc_entity",
        "owned_by_sanctioned_usa_ofac_non_sdn_entity",
        "owned_by_sanctioned_usa_ofac_sdn_entity",
        "owned_by_sanctioned_xxx_ebrd_entity",
        "owned_by_sanctioned_xxx_iabd_entity",
        "owned_by_section_1260h_entity",
        "owned_by_sheffield_hallam_university_reports_forced_labor_entity",
        "owned_by_soe",
        "owned_by_usa_aeca_debarred_entity",
        "owned_by_usa_bis_denied_persons_entity",
        "owned_by_usa_bis_entity",
        "owned_by_usa_bis_meu_entity",
        "owned_by_usa_bis_unverified_entity",
        "owned_by_usa_isn_entity",
        "owned_by_usa_section_1260h_entity",
        "owned_by_wro_entity",
        "owned_by_xinjiang_entity",
        "owner_of_aspi_forced_labor_entity",
        "owner_of_chinese_soe",
        "owner_of_export_controls_entity",
        "owner_of_forced_labor_xinjiang_entity",
        "owner_of_forced_labor_xinjiang_uflpa",
        "owner_of_jpn_meti_end_user_entity",
        "owner_of_jpn_mofa_export_ban_entity",
        "owner_of_ofac_fto_sanctioned",
        "owner_of_ofac_illicit_drugs_eo14059_sanctioned",
        "owner_of_ofac_sdgt_sanctioned",
        "owner_of_ofac_sdn_mex_dto_sanctioned",
        "owner_of_ofac_sdnt_sanctioned",
        "owner_of_ofac_sdntk_sanctioned",
        "owner_of_regulatory_action_entity",
        "owner_of_sanctioned_arg_repet_jus_entity",
        "owner_of_sanctioned_aus_dfat_entity",
        "owner_of_sanctioned_bel_fpsf_entity",
        "owner_of_sanctioned_can_gac_entity",
        "owner_of_sanctioned_che_seco_entity",
        "owner_of_sanctioned_cze_mof_entity",
        "owner_of_sanctioned_entity",
        "owner_of_sanctioned_eu_dg_fisma_ec_entity",
        "owner_of_sanctioned_eu_ec_regulation_833_2014_entity",
        "owner_of_sanctioned_eu_ec_sanctions_map_entity",
        "owner_of_sanctioned_eu_sanctions_entity",
        "owner_of_sanctioned_fra_dgt_mefids_entity",
        "owner_of_sanctioned_gbr_fcdo_entity",
        "owner_of_sanctioned_gbr_hmt_ofsi_entity",
        "owner_of_sanctioned_isr_mod_nbctf_entity",
        "owner_of_sanctioned_jpn_mof_entity",
        "owner_of_sanctioned_ltu_mi_entity",
        "owner_of_sanctioned_lva_fis_entity",
        "owner_of_sanctioned_mys_moha_entity",
        "owner_of_sanctioned_nld_mofa_entity",
        "owner_of_sanctioned_nzl_mfat_rus_entity",
        "owner_of_sanctioned_pol_mia_entity",
        "owner_of_sanctioned_sgp_agc_entity",
        "owner_of_sanctioned_ukr_nsdc_entity",
        "owner_of_sanctioned_ukr_sfms_entity",
        "owner_of_sanctioned_un_sc_entity",
        "owner_of_sanctioned_usa_ofac_non_sdn_entity",
        "owner_of_sanctioned_usa_ofac_sdn_entity",
        "owner_of_sanctioned_xxx_ebrd_entity",
        "owner_of_sanctioned_xxx_iabd_entity",
        "owner_of_sheffield_hallam_university_reports_forced_labor_entity",
        "owner_of_soe",
        "owner_of_usa_aeca_debarred_entity",
        "owner_of_usa_bis_denied_persons_entity",
        "owner_of_usa_bis_entity",
        "owner_of_usa_bis_meu_entity",
        "owner_of_usa_bis_unverified_entity",
        "owner_of_usa_isn_entity",
        "owner_of_usa_section_1260h_entity",
        "owner_of_wro_entity",
        "pep",
        "pep_adjacent",
        "psa_bis_boycott_requester_list",
        "psa_chinese_state_owned",
        "psa_cmic_entity_50_percent_rule",
        "psa_entity_licensed_with_fsb_rf",
        "psa_eu_50_percent_rule",
        "psa_eu_minority_ownership",
        "psa_export_controls",
        "psa_export_controls_bis_entity_50_percent_rule",
        "psa_export_controls_bis_meu_50_percent_rule",
        "psa_export_controls_section_1260h_50_percent_rule",
        "psa_export_controls_unverified_list_50_percent_rule",
        "psa_export_to_chinese_soe",
        "psa_export_to_sanctioned",
        "psa_export_to_soe",
        "psa_exports_bis_high_priority_items_critical_components_direct",
        "psa_exports_bis_high_priority_items_critical_components_indirect",
        "psa_exports_bis_high_priority_items_direct",
        "psa_exports_bis_high_priority_items_indirect",
        "psa_exports_conflict_minerals",
        "psa_exports_eudr_shipment_cattle",
        "psa_exports_eudr_shipment_cocoa",
        "psa_exports_eudr_shipment_coffee",
        "psa_exports_eudr_shipment_palm_oil",
        "psa_exports_eudr_shipment_rubber",
        "psa_exports_eudr_shipment_soya",
        "psa_exports_eudr_shipment_wood",
        "psa_exports_ilab_child_labor",
        "psa_exports_ilab_forced_labor",
        "psa_exports_russian_coal",
        "psa_exports_russian_gold",
        "psa_exports_russian_important_good",
        "psa_exports_russian_oil",
        "psa_exports_to_bis_addresses_high_diversion_risk",
        "psa_exports_to_entity_licensed_with_fsb_rf",
        "psa_exports_to_jpn_meti_end_user_entity",
        "psa_exports_to_jpn_mofa_export_ban_entity",
        "psa_exports_to_sanctioned_arg_repet_jus_entity",
        "psa_exports_to_sanctioned_aus_dfat_entity",
        "psa_exports_to_sanctioned_bel_fpsf_entity",
        "psa_exports_to_sanctioned_can_gac_entity",
        "psa_exports_to_sanctioned_che_seco_entity",
        "psa_exports_to_sanctioned_cze_mof_entity",
        "psa_exports_to_sanctioned_eu_dg_fisma_ec_entity",
        "psa_exports_to_sanctioned_eu_ec_regulation_833_2014_entity",
        "psa_exports_to_sanctioned_eu_ec_sanctions_map_entity",
        "psa_exports_to_sanctioned_eu_sanctions_entity",
        "psa_exports_to_sanctioned_fra_dgt_mefids_entity",
        "psa_exports_to_sanctioned_gbr_fcdo_entity",
        "psa_exports_to_sanctioned_gbr_hmt_ofsi_entity",
        "psa_exports_to_sanctioned_isr_mod_nbctf_entity",
        "psa_exports_to_sanctioned_jpn_mof_entity",
        "psa_exports_to_sanctioned_ltu_mi_entity",
        "psa_exports_to_sanctioned_lva_fis_entity",
        "psa_exports_to_sanctioned_mys_moha_entity",
        "psa_exports_to_sanctioned_nld_mofa_entity",
        "psa_exports_to_sanctioned_nzl_mfat_rus_entity",
        "psa_exports_to_sanctioned_pol_mia_entity",
        "psa_exports_to_sanctioned_sgp_agc_entity",
        "psa_exports_to_sanctioned_ukr_nsdc_entity",
        "psa_exports_to_sanctioned_ukr_sfms_entity",
        "psa_exports_to_sanctioned_un_sc_entity",
        "psa_exports_to_sanctioned_usa_ofac_non_sdn_entity",
        "psa_exports_to_sanctioned_usa_ofac_sdn_entity",
        "psa_exports_to_sanctioned_xxx_ebrd_entity",
        "psa_exports_to_sanctioned_xxx_iabd_entity",
        "psa_exports_to_usa_aeca_debarred_entity",
        "psa_exports_to_usa_bis_denied_persons_entity",
        "psa_exports_to_usa_bis_entity",
        "psa_exports_to_usa_bis_meu_entity",
        "psa_exports_to_usa_bis_unverified_entity",
        "psa_exports_to_usa_isn_entity",
        "psa_exports_to_usa_section_1260h_entity",
        "psa_forced_labor_aspi_origin_direct",
        "psa_forced_labor_aspi_origin_subtier",
        "psa_forced_labor_aspi_uyghur",
        "psa_forced_labor_sheffield_hallam_university_reports_origin_direct",
        "psa_forced_labor_sheffield_hallam_university_reports_origin_subtier",
        "psa_forced_labor_uflpa_origin_direct",
        "psa_forced_labor_uflpa_origin_subtier",
        "psa_forced_labor_wro_origin_direct",
        "psa_forced_labor_wro_origin_subtier",
        "psa_forced_labor_xinjiang_cotton_entity",
        "psa_forced_labor_xinjiang_geospatial",
        "psa_forced_labor_xinjiang_name",
        "psa_forced_labor_xinjiang_operations",
        "psa_forced_labor_xinjiang_origin_direct",
        "psa_forced_labor_xinjiang_origin_subtier",
        "psa_forced_labor_xinjiang_registration",
        "psa_forced_labor_xinjiang_uflpa",
        "psa_imports_bis_high_priority_items",
        "psa_imports_bis_high_priority_items_critical_components",
        "psa_imports_conflict_minerals",
        "psa_imports_eudr_shipment_cattle",
        "psa_imports_eudr_shipment_cocoa",
        "psa_imports_eudr_shipment_coffee",
        "psa_imports_eudr_shipment_palm_oil",
        "psa_imports_eudr_shipment_rubber",
        "psa_imports_eudr_shipment_soya",
        "psa_imports_eudr_shipment_wood",
        "psa_imports_from_bis_addresses_high_diversion_risk",
        "psa_imports_ilab_child_labor",
        "psa_imports_ilab_forced_labor",
        "psa_imports_ndaa_889_telecom_equipment",
        "psa_imports_russian_coal",
        "psa_imports_russian_gold",
        "psa_imports_russian_important_good",
        "psa_imports_russian_oil",
        "psa_jpn_meti_end_user",
        "psa_jpn_mofa_export_ban",
        "psa_military_civil_fusion",
        "psa_military_civil_fusion_50_percent_rule",
        "psa_ofac_50_percent_rule",
        "psa_ofac_minority_ownership",
        "psa_ofac_sdn_mex_dto_sanctioned_adjacent",
        "psa_owned_by_aspi_forced_labor_entity",
        "psa_owned_by_bis_meu_entity",
        "psa_owned_by_chinese_soe",
        "psa_owned_by_cmic_entity",
        "psa_owned_by_entity_in_export_controls",
        "psa_owned_by_forced_labor_xinjiang_uflpa",
        "psa_owned_by_jpn_meti_end_user_entity",
        "psa_owned_by_jpn_mofa_export_ban_entity",
        "psa_owned_by_military_civil_fusion",
        "psa_owned_by_ofac_fto_sanctioned",
        "psa_owned_by_ofac_illicit_drugs_eo14059_sanctioned",
        "psa_owned_by_ofac_sdgt_sanctioned",
        "psa_owned_by_ofac_sdn_mex_dto_sanctioned",
        "psa_owned_by_ofac_sdnt_sanctioned",
        "psa_owned_by_ofac_sdntk_sanctioned",
        "psa_owned_by_sanctioned_arg_repet_jus_entity",
        "psa_owned_by_sanctioned_aus_dfat_entity",
        "psa_owned_by_sanctioned_bel_fpsf_entity",
        "psa_owned_by_sanctioned_can_gac_entity",
        "psa_owned_by_sanctioned_che_seco_entity",
        "psa_owned_by_sanctioned_cze_mof_entity",
        "psa_owned_by_sanctioned_entity",
        "psa_owned_by_sanctioned_eu_dg_fisma_ec_entity",
        "psa_owned_by_sanctioned_eu_ec_regulation_833_2014_entity",
        "psa_owned_by_sanctioned_eu_ec_sanctions_map_entity",
        "psa_owned_by_sanctioned_eu_sanctions_entity",
        "psa_owned_by_sanctioned_fra_dgt_mefids_entity",
        "psa_owned_by_sanctioned_gbr_fcdo_entity",
        "psa_owned_by_sanctioned_gbr_hmt_ofsi_entity",
        "psa_owned_by_sanctioned_isr_mod_nbctf_entity",
        "psa_owned_by_sanctioned_jpn_mof_entity",
        "psa_owned_by_sanctioned_ltu_mi_entity",
        "psa_owned_by_sanctioned_lva_fis_entity",
        "psa_owned_by_sanctioned_mys_moha_entity",
        "psa_owned_by_sanctioned_nld_mofa_entity",
        "psa_owned_by_sanctioned_nzl_mfat_rus_entity",
        "psa_owned_by_sanctioned_pol_mia_entity",
        "psa_owned_by_sanctioned_sgp_agc_entity",
        "psa_owned_by_sanctioned_ukr_nsdc_entity",
        "psa_owned_by_sanctioned_ukr_sfms_entity",
        "psa_owned_by_sanctioned_un_sc_entity",
        "psa_owned_by_sanctioned_usa_ofac_non_sdn_entity",
        "psa_owned_by_sanctioned_usa_ofac_sdn_entity",
        "psa_owned_by_sanctioned_xxx_ebrd_entity",
        "psa_owned_by_sanctioned_xxx_iabd_entity",
        "psa_owned_by_section_1260h_entity",
        "psa_owned_by_sheffield_hallam_university_reports_forced_labor_entity",
        "psa_owned_by_soe",
        "psa_owned_by_usa_aeca_debarred_entity",
        "psa_owned_by_usa_bis_denied_persons_entity",
        "psa_owned_by_usa_bis_entity",
        "psa_owned_by_usa_bis_meu_entity",
        "psa_owned_by_usa_bis_unverified_entity",
        "psa_owned_by_usa_isn_entity",
        "psa_owned_by_usa_section_1260h_entity",
        "psa_owned_by_wro_entity",
        "psa_owned_by_xinjiang_entity",
        "psa_owner_of_aspi_forced_labor_entity",
        "psa_owner_of_chinese_soe",
        "psa_owner_of_export_controls_entity",
        "psa_owner_of_forced_labor_xinjiang_entity",
        "psa_owner_of_forced_labor_xinjiang_uflpa",
        "psa_owner_of_jpn_meti_end_user_entity",
        "psa_owner_of_jpn_mofa_export_ban_entity",
        "psa_owner_of_ofac_fto_sanctioned",
        "psa_owner_of_ofac_illicit_drugs_eo14059_sanctioned",
        "psa_owner_of_ofac_sdgt_sanctioned",
        "psa_owner_of_ofac_sdn_mex_dto_sanctioned",
        "psa_owner_of_ofac_sdnt_sanctioned",
        "psa_owner_of_ofac_sdntk_sanctioned",
        "psa_owner_of_regulatory_action_entity",
        "psa_owner_of_sanctioned_arg_repet_jus_entity",
        "psa_owner_of_sanctioned_aus_dfat_entity",
        "psa_owner_of_sanctioned_bel_fpsf_entity",
        "psa_owner_of_sanctioned_can_gac_entity",
        "psa_owner_of_sanctioned_che_seco_entity",
        "psa_owner_of_sanctioned_cze_mof_entity",
        "psa_owner_of_sanctioned_entity",
        "psa_owner_of_sanctioned_eu_dg_fisma_ec_entity",
        "psa_owner_of_sanctioned_eu_ec_regulation_833_2014_entity",
        "psa_owner_of_sanctioned_eu_ec_sanctions_map_entity",
        "psa_owner_of_sanctioned_eu_sanctions_entity",
        "psa_owner_of_sanctioned_fra_dgt_mefids_entity",
        "psa_owner_of_sanctioned_gbr_fcdo_entity",
        "psa_owner_of_sanctioned_gbr_hmt_ofsi_entity",
        "psa_owner_of_sanctioned_isr_mod_nbctf_entity",
        "psa_owner_of_sanctioned_jpn_mof_entity",
        "psa_owner_of_sanctioned_ltu_mi_entity",
        "psa_owner_of_sanctioned_lva_fis_entity",
        "psa_owner_of_sanctioned_mys_moha_entity",
        "psa_owner_of_sanctioned_nld_mofa_entity",
        "psa_owner_of_sanctioned_nzl_mfat_rus_entity",
        "psa_owner_of_sanctioned_pol_mia_entity",
        "psa_owner_of_sanctioned_sgp_agc_entity",
        "psa_owner_of_sanctioned_ukr_nsdc_entity",
        "psa_owner_of_sanctioned_ukr_sfms_entity",
        "psa_owner_of_sanctioned_un_sc_entity",
        "psa_owner_of_sanctioned_usa_ofac_non_sdn_entity",
        "psa_owner_of_sanctioned_usa_ofac_sdn_entity",
        "psa_owner_of_sanctioned_xxx_ebrd_entity",
        "psa_owner_of_sanctioned_xxx_iabd_entity",
        "psa_owner_of_sheffield_hallam_university_reports_forced_labor_entity",
        "psa_owner_of_soe",
        "psa_owner_of_usa_aeca_debarred_entity",
        "psa_owner_of_usa_bis_denied_persons_entity",
        "psa_owner_of_usa_bis_entity",
        "psa_owner_of_usa_bis_meu_entity",
        "psa_owner_of_usa_bis_unverified_entity",
        "psa_owner_of_usa_isn_entity",
        "psa_owner_of_usa_section_1260h_entity",
        "psa_owner_of_wro_entity",
        "psa_pep",
        "psa_regulatory_action",
        "psa_sanctioned",
        "psa_sanctioned_arg_repet_jus",
        "psa_sanctioned_aus_dfat",
        "psa_sanctioned_bel_fpsf",
        "psa_sanctioned_can_gac",
        "psa_sanctioned_che_seco",
        "psa_sanctioned_cze_mof",
        "psa_sanctioned_eu_dg_fisma_ec",
        "psa_sanctioned_eu_ec_regulation_833_2014",
        "psa_sanctioned_eu_ec_sanctions_map",
        "psa_sanctioned_eu_sanctions",
        "psa_sanctioned_fra_dgt_mefids",
        "psa_sanctioned_gbr_fcdo",
        "psa_sanctioned_gbr_hmt_ofsi",
        "psa_sanctioned_isr_mod_nbctf",
        "psa_sanctioned_jpn_mof",
        "psa_sanctioned_ltu_mi",
        "psa_sanctioned_lva_fis",
        "psa_sanctioned_mys_moha",
        "psa_sanctioned_nld_mofa",
        "psa_sanctioned_nzl_mfat_rus",
        "psa_sanctioned_pol_mia",
        "psa_sanctioned_sgp_agc",
        "psa_sanctioned_ukr_nsdc",
        "psa_sanctioned_ukr_sfms",
        "psa_sanctioned_un_sc",
        "psa_sanctioned_usa_ofac_non_sdn",
        "psa_sanctioned_usa_ofac_sdn",
        "psa_sanctioned_xxx_ebrd",
        "psa_sanctioned_xxx_iabd",
        "psa_sheffield_hallam_university_forced_labor_entity",
        "psa_sheffield_hallam_university_intermediary_entity",
        "psa_sheffield_hallam_university_useful_resources",
        "psa_state_owned",
        "psa_state_owned_ven",
        "psa_uk_50_percent_rule",
        "psa_uk_minority_ownership",
        "psa_usa_aeca_debarred",
        "psa_usa_bis",
        "psa_usa_bis_50_percent_rule",
        "psa_usa_bis_denied_persons",
        "psa_usa_bis_meu",
        "psa_usa_bis_meu_50_percent_rule",
        "psa_usa_bis_unverified",
        "psa_usa_isn",
        "psa_usa_section_1260h",
        "psa_ven_soe_50_percent",
        "psa_wro_entity",
        "regulatory_action",
        "reputational_risk_bribery_and_corruption",
        "reputational_risk_cybercrime",
        "reputational_risk_financial_crime",
        "reputational_risk_forced_labor",
        "reputational_risk_organized_crime",
        "reputational_risk_other",
        "reputational_risk_terrorism",
        "sanctioned",
        "sanctioned_adjacent",
        "sanctioned_arg_repet_jus",
        "sanctioned_aus_dfat",
        "sanctioned_bel_fpsf",
        "sanctioned_can_gac",
        "sanctioned_che_seco",
        "sanctioned_cze_mof",
        "sanctioned_eu_dg_fisma_ec",
        "sanctioned_eu_ec_regulation_269_2014",
        "sanctioned_eu_ec_regulation_833_2014",
        "sanctioned_eu_ec_sanctions_map",
        "sanctioned_eu_sanctions",
        "sanctioned_fra_dgt_mefids",
        "sanctioned_gbr_fcdo",
        "sanctioned_gbr_hmt_ofsi",
        "sanctioned_isr_mod_nbctf",
        "sanctioned_jpn_mof",
        "sanctioned_ltu_mi",
        "sanctioned_lva_fis",
        "sanctioned_mys_moha",
        "sanctioned_nld_mofa",
        "sanctioned_nzl_mfat_rus",
        "sanctioned_pol_mia",
        "sanctioned_sgp_agc",
        "sanctioned_ukr_nsdc",
        "sanctioned_ukr_sfms",
        "sanctioned_un_sc",
        "sanctioned_usa_ofac_non_sdn",
        "sanctioned_usa_ofac_sdn",
        "sanctioned_xxx_ebrd",
        "sanctioned_xxx_iabd",
        "sheffield_hallam_university_forced_labor_entity",
        "sheffield_hallam_university_forced_labor_reports_entity_adjacent",
        "sheffield_hallam_university_forced_labor_reports_intermediary_entity",
        "sheffield_hallam_university_useful_resources",
        "soe_adjacent",
        "state_owned",
        "state_owned_ven",
        "subsidiary_of_ndaa_889_covered_entities",
        "uk_50_percent_rule",
        "uk_minority_ownership",
        "uk_sanctioned",
        "usa_aeca_debarred",
        "usa_bis",
        "usa_bis_50_percent_rule",
        "usa_bis_denied_persons",
        "usa_bis_meu",
        "usa_bis_meu_50_percent_rule",
        "usa_bis_unverified",
        "usa_isn",
        "usa_section_1260h",
        "ven_soe_50_percent",
        "wro_entity",
        "wro_entity_adjacent",
    ],
    typing.Any,
]
